@@ -30,6 +30,7 @@
 #include "../smplayer/extensions.h"
 #include "../messagedialog.h"
 #include "../smplayer/infoprovider.h"
+#include "../smplayer/cleanconfig.h"
 
 #include <QFile>
 #include <QTextStream>
@@ -1027,12 +1028,51 @@ void Playlist::playNext()
 
 void Playlist::playPrev()
 {
-    if (m_currentItemIndex > 0) {
-        playItem(m_currentItemIndex - 1);
+    if (pref->play_order == Preferences::RandomPlay) {//随机播放
+        int chosen_item = chooseRandomItem();
+        if (chosen_item == -1) {
+            clearPlayedTag();
+            chosen_item = chooseRandomItem();
+            if (chosen_item == -1) chosen_item = 0;
+        }
+        playItem(chosen_item);
     }
-    else {
-        if (this->m_playlistView->getModelRowCount() > 1) {
-            playItem(this->m_playlistView->getModelRowCount() - 1);
+    else if (pref->play_order == Preferences::ListLoopPlay) {//列表循环
+        bool top_list = (m_currentItemIndex == 0) ? true : false;
+        if (top_list) {
+            clearPlayedTag();
+        }
+        if (top_list) {
+            playItem(0);
+        }
+        else {
+            if (m_currentItemIndex > 0) {
+                playItem(m_currentItemIndex - 1);
+            }
+            else {
+                if (this->m_playlistView->getModelRowCount() > 1) {
+                    playItem(this->m_playlistView->getModelRowCount() - 1);
+                }
+            }
+        }
+    }
+    else {//顺序播放
+        bool top_list = (m_currentItemIndex == 0) ? true : false;
+        if (top_list) {
+            clearPlayedTag();
+        }
+        if (top_list) {
+            emit this->showMessage(tr("Reached the top of the playlist"));
+        }
+        else {
+            if (m_currentItemIndex > 0) {
+                playItem(m_currentItemIndex - 1);
+            }
+            else {
+                if (this->m_playlistView->getModelRowCount() > 1) {
+                    playItem(this->m_playlistView->getModelRowCount() - 1);
+                }
+            }
         }
     }
 }
@@ -1131,6 +1171,7 @@ void Playlist::onPlayListChanged(const VideoPtrList medialist)
     set->endArray();
     set->setValue("current_item", m_currentItemIndex);
     set->endGroup();
+    set->sync();
 
     // update ui
     this->m_playlistView->onPlayListChanged(/*medialist*/);
@@ -1280,7 +1321,7 @@ void Playlist::onPlayListItemDeleteBtnClicked(const QStringList &filepathlist)
 //        MessageDialog msgDialog(0, tr("Confirm remove"),
 //                                tr("You're about to remove the file '%1' from the playlist.").arg(filename) + "<br>"+
 //                                tr("Are you sure you want to proceed?"), QMessageBox::Yes | QMessageBox::No);
-        MessageDialog msgDialog(0, tr("Confirm remove"),
+        MessageDialog msgDialog(this, tr("Confirm remove"),
                                 tr("You're about to remove the file from the playlist.") + "<br>"+
                                 tr("Are you sure you want to proceed?"), QMessageBox::Yes | QMessageBox::No);
         if (msgDialog.exec() != -1) {
@@ -1316,6 +1357,7 @@ void Playlist::onPlayListItemDeleteBtnClicked(const QStringList &filepathlist)
                     set->endArray();
                     set->setValue("current_item", m_currentItemIndex);
                     set->endGroup();
+                    set->sync();
 
                     // Step3 : update ui
                     this->m_playlistView->removeFilesFromPlayList(filepathlist);
@@ -1351,7 +1393,7 @@ void Playlist::deleteSelectedFileFromDisk(const QStringList &filepathlist)
 
     if (!filepathlist.isEmpty()) {
         // Ask the user for confirmation
-        MessageDialog msgDialog(0, tr("Confirm deletion"),
+        MessageDialog msgDialog(this, tr("Confirm deletion"),
                                 tr("You're about to Delete the files from your drive.") + "<br>"+
                                 tr("This action cannot be undone. Are you sure you want to proceed?"), QMessageBox::Yes | QMessageBox::No);
         if (msgDialog.exec() != -1) {
@@ -1395,6 +1437,7 @@ void Playlist::deleteSelectedFileFromDisk(const QStringList &filepathlist)
                     set->endArray();
                     set->setValue("current_item", m_currentItemIndex);
                     set->endGroup();
+                    set->sync();
 
                     // Step3 : update ui
                     this->m_playlistView->removeFilesFromPlayList(deletedList);
@@ -1425,12 +1468,16 @@ void Playlist::deleteSelectedFileFromDisk(const QStringList &filepathlist)
 
 void Playlist::removeAll()
 {
-    MessageDialog msgDialog(0, tr("Confirm remove all"),
+    MessageDialog msgDialog(this, tr("Confirm remove all"),
                             tr("You're about to empty the playlist.") + "<br>"+
                             tr("Are you sure you want to proceed?"), QMessageBox::Yes | QMessageBox::No);
     if (msgDialog.exec() != -1) {
         if (msgDialog.standardButton(msgDialog.clickedButton()) == QMessageBox::Yes) {
             if (set) {
+                // stop play
+                emit this->cleanPlaylistFinished();
+                emit this->requestSetPlayingTitle("");
+
                 // Step 1: update pref->m_videoMap
                 pref->m_videoMap.clear();
 
@@ -1440,6 +1487,9 @@ void Playlist::removeAll()
                 // Step3 : update ui && update count
                 clear();
                 setPlaylistFilename("");
+
+                //删除播放列表的时候，将存放视频文件详细信息的其他配置文件删除
+                CleanConfig::clean(Paths::configPath());
             }
         }
     }
@@ -1465,7 +1515,10 @@ int Playlist::chooseRandomItem()
 
     if (fi.count() == 0) return -1; // none free
 
-    int selected = (int) ((double) this->count() * rand()/(RAND_MAX+1.0));
+    //解决随机播放时，随机数大于播放列表总数时导致上一曲和下一曲按钮功能失效的问题
+    //int selected = (int) ((double) this->count() * rand()/(RAND_MAX+1.0));
+    int selected = (int) ((double) fi.count() * rand()/(RAND_MAX+1.0));
+
     return fi[selected];
 }
 
@@ -1738,12 +1791,15 @@ void Playlist::onResortVideos(const QStringList &sortList, int index)
     set->setValue("current_item", m_currentItemIndex);
     set->endGroup();
 
+    set->sync();
+
     //read form ini file
     pref->m_videoMap.clear();
     set->beginGroup("playlist_contents");
     int itemIndex = set->value("current_item", -1).toInt();
     this->m_currentItemIndex = itemIndex;
     int count = set->beginReadArray("items");
+//    int count = set->value("count", 0).toInt();
     QString filename, name;
     double duration;
     for (int n = 0; n < count; n++) {
@@ -1760,6 +1816,16 @@ void Playlist::onResortVideos(const QStringList &sortList, int index)
     set->endGroup();
 }
 
+void Playlist::updatePlayOrderSettings()
+{
+    if (!set) return;
+
+    set->beginGroup("playlist_contents");
+    set->setValue("play_order", (int) pref->play_order);
+    set->endGroup();
+    set->sync();
+}
+
 void Playlist::saveSettings()
 {
     if (!set) return;
@@ -1771,8 +1837,20 @@ void Playlist::saveSettings()
     //Save current list
     set->remove("playlist_contents");
     set->beginGroup("playlist_contents");
+//    set->setValue("count", (int)pl.count());
     set->beginWriteArray("items");
     int index = 0;
+    QMap<QString, VideoPtr>::iterator i;
+    for (i = pref->m_videoMap.begin(); i != pref->m_videoMap.end(); ++i) {
+        set->setArrayIndex(index);
+        set->setValue(QString("item_%1_filename").arg(index), i.value()->localpath());
+        set->setValue(QString("item_%1_duration").arg(index), i.value()->duration());
+        set->setValue(QString("item_%1_name").arg(index), i.value()->name());
+        index ++;
+    }
+
+    //将会导致切换播放引擎时，播放列表被清空
+    /*
     for (int row = 0; row < this->m_playlistView->getModelRowCount(); row++ ) {
         QString filepath = this->m_playlistView->getFileNameByRow(row);
         //Q_ASSERT(!filepath.isEmpty());
@@ -1789,20 +1867,32 @@ void Playlist::saveSettings()
                 break;
             }
         }
-    }
+    }*/
     set->endArray();
     set->setValue("current_item", m_currentItemIndex);
+    set->setValue("play_order", (int) pref->play_order);
     set->endGroup();
+    set->sync();
 }
 
 void Playlist::loadSettings()
 {
     if (!set) return;
 
+    /*QStringList groups = set->childGroups();
+    foreach (QString group, groups) {//列出所有子组
+        qDebug() << "group:" << group;
+    }*/
+
     //Load latest list
     set->beginGroup("playlist_contents");
+
+    //playlist_load_latest_dir = set->value("laylist_load_latest_dir", playlist_load_latest_dir).toString();//latest_dir  0526
+    pref->play_order = (Preferences::PlayOrder) set->value("play_order", (int) pref->play_order).toInt();//20170725
+
     int index = set->value("current_item", -1).toInt();
     int count = set->beginReadArray("items");
+//    int count = set->value("count", 0).toInt();
     QString filename, name;
     double duration;
     for (int n = 0; n < count; n++) {
@@ -1823,16 +1913,21 @@ void Playlist::loadSettings()
     latest_dir = set->value("latest_dir", latest_dir).toString();
     set->endGroup();
 
+
+    //界面播放引擎切换后，播放列表被清空的问题
+    // update ui
+    this->m_playlistView->onPlayListChanged();
     int currentCount = this->count();
     emit this->update_playlist_count(currentCount);
     if (currentCount > 0) {
-        noVideoFrame->hide();
-        m_playlistView->show();
+        noVideoFrame->setVisible(false);
+        m_playlistView->setVisible(true);
     }
     else {
+        m_currentItemIndex = 0;
         this->setPlaying("", 0);
-        noVideoFrame->show();
-        m_playlistView->hide();
+        noVideoFrame->setVisible(true);
+        m_playlistView->setVisible(false);
     }
 }
 
