@@ -3,19 +3,24 @@
 #include <QDir>
 
 void CleanConfig::clean(const QString & config_path) {
-	qDebug("CleanConfig::clean");
+    //qDebug("CleanConfig::clean");
 
 	QStringList files_to_delete;
 
+    //老版本的配置文件kylin-video-files.ini
+    QString tmp_s = config_path + "/kylin-video-files.ini";
+    if (QFile::exists(tmp_s)) files_to_delete << tmp_s;
+
+    //新版本的配置文件kylin-video-files.ini
     QString s = config_path + "/kylin_video_files.ini";
     if (QFile::exists(s)) files_to_delete << s;
 	
     s = config_path + "/player_info.ini";
 	if (QFile::exists(s)) files_to_delete << s;
 
-	printf("Deleting files:\n");
+    //printf("Deleting files:\n");
 	for (int n = 0; n < files_to_delete.count(); n++) {
-		printf("Delete: %s\n", files_to_delete[n].toUtf8().constData());
+        //printf("Delete: %s\n", files_to_delete[n].toUtf8().constData());
 		QFile::remove(files_to_delete[n]);
 	}
 }
