@@ -16,34 +16,50 @@
     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
-#ifndef _INFOFILE_H_
-#define _INFOFILE_H_
+#ifndef INFOFILE_H
+#define INFOFILE_H
 
 #include "mediadata.h"
+#include "tracks.h"
+#include "subtracks.h"
 #include <QString>
+#include <QObject>
 
-class InfoFile 
+#define INFO_SIMPLE_LAYOUT
+
+class InfoFile/* : public QObject*/
 {
+//    Q_OBJECT
 
 public:
-	InfoFile();
-	~InfoFile();
+    InfoFile(/*QObject * parent = 0*/);
+    ~InfoFile();
 
-	QString getInfo(MediaData md);
+    QString getInfo(MediaData md, Tracks videos, Tracks audios, SubTracks subs);
 
 protected:
-	QString title(QString text);
+    QString title(QString text, QString icon);//QString title(QString text);
 	QString openPar(QString text);
 	QString closePar();
 	QString openItem();
 	QString closeItem();
 
+    QString addTrackColumns(QStringList l);
+
 	QString addItem( QString tag, QString value );
+    QString addTrack(int n, QString lang, QString name, int ID, QString type = "");
+
+    QString defaultStyle();
 
 	int row;
 
 private:
-	inline QString tr( const char * sourceText, const char * comment = 0, int n = -1 );
+    inline QString kylin_tr( const char * sourceText, const char * comment = 0, int n = -1 );
+
+
+#ifndef INFO_SIMPLE_LAYOUT
+    int row;
+#endif
 };
 
 #endif
