@@ -83,7 +83,7 @@ void MplayerProcess::setOption(const QString & option_name, const QVariant & val
         QString ao = value.toString();
         if (ao.contains(":")) {
             QStringList l = DeviceInfo::extractDevice(ao);
-            qDebug() << "MplayerProcess::setOption: ao:" << l;
+            //qDebug() << "MplayerProcess::setOption: ao:" << l;
             if (l.count() > 1) {
 //                #ifndef Q_OS_WIN
                 if (l[0] == "alsa") {
@@ -505,7 +505,6 @@ void MplayerProcess::enableVolnorm(bool b, const QString & option) {
 //	writeToStdin("af_cmdline equalizer " + values);
 //}
 void MplayerProcess::setAudioEqualizer(AudioEqualizerList l) {
-    qDebug() << "equalizerListToString start 222";
     QString values = AudioEqualizerHelper::equalizerListToString(l);
     writeToStdin("af_cmdline equalizer " + values);
 }
@@ -535,7 +534,6 @@ void MplayerProcess::clearABMarkers() {
 }
 
 void MplayerProcess::takeScreenshot(ScreenshotType t, bool /*include_subtitles*/) {
-    qDebug() << "MplayerProcess::takeScreenshot";
 	if (t == Single) {
 		writeToStdin(pausing_prefix + " screenshot 0");
 	} else {
