@@ -28,8 +28,7 @@ TimeDialog::TimeDialog( QWidget* parent, Qt::WindowFlags f )
     , m_startDrag(QPoint(0,0))
 {
 	setupUi(this);
-
-    this->setWindowFlags(Qt::FramelessWindowHint);
+    this->setWindowFlags(Qt::Dialog | Qt::FramelessWindowHint);
     this->setFixedSize(380, 170);
     this->setStyleSheet("QDialog{border: 1px solid #121212;border-radius:1px;background-color:#1f1f1f;}");
     this->setWindowIcon(QIcon::fromTheme("kylin-video", QIcon(":/res/kylin-video.png")));
