@@ -145,9 +145,13 @@ void TimeSlider::enterEvent(QEvent *)
     emit this->active_status(true);
 }
 
-void TimeSlider::leaveEvent(QEvent *)
+void TimeSlider::leaveEvent(QEvent *event)
 {
     emit this->active_status(false);
+
+    emit requestHideTip();
+    event->ignore();
+    QSlider::leaveEvent(event);
 }
 
 void TimeSlider::show_time_value(int time)
@@ -212,7 +216,7 @@ bool TimeSlider::event(QEvent *event) {
 		if (time >= 0 && time <= total_time) {
             //QToolTip::showText(help_event->globalPos(), Utils::formatTime(time), this);
             if (preview) {
-                emit this->requestSavePreviewImage(time);
+                emit this->requestSavePreviewImage(time, cur_pos);
             }
             else {
                 hintWidget->setText(Utils::formatTime(time));
