@@ -23,35 +23,40 @@
 #include <QApplication>
 #include <QDebug>
 
-Translator::Translator() {
-	qApp->installTranslator( &app_trans );
-    qApp->installTranslator( &qt_trans );
+Translator::Translator()
+{
+    qApp->installTranslator(&app_trans);
+    qApp->installTranslator(&qt_trans);
 }
 
-Translator::~Translator() {
+Translator::~Translator()
+{
 }
 
-bool Translator::loadCatalog(QTranslator & t, QString name, QString locale, QString dir) {
-        QString s = name + "_" + locale + ".qm"; //.toLower();
+bool Translator::loadCatalog(QTranslator & t, QString name, QString locale, QString dir)
+{
+    QString s = name + "_" + locale + ".qm"; //.toLower();
 	bool r = t.load(s, dir);
-	if (r) 
-		qDebug("Translator::loadCatalog: successfully loaded %s from %s", s.toUtf8().data(), dir.toUtf8().data());
-	else
+    if (!r) {
 		qDebug("Translator::loadCatalog: can't load %s from %s", s.toUtf8().data(), dir.toUtf8().data());
+    }
 	return r;
 }
 
-void Translator::load(/*QString locale*/) {
+void Translator::load(const QString &snap)
+{
     QString locale = QLocale::system().name();
 
 	QString trans_path = Paths::translationPath();
-    QString qt_trans_path = Paths::qtTranslationPath();
 
-	// In linux try to load it first from app path (in case there's an updated
-    // translation), if it fails it will try then from the Qt path.
-//	if (! loadCatalog(qt_trans, "qt", locale, trans_path ) ) {
+    QString qt_trans_path;
+    if (!snap.isEmpty()) {
+        qt_trans_path = QString("%1%2").arg(snap).arg(Paths::qtTranslationPath());
+    }
+    else {
+        qt_trans_path = Paths::qtTranslationPath();
+    }
+
     loadCatalog(qt_trans, "qt", locale, qt_trans_path);
-//	}
-
     loadCatalog(app_trans, "kylin-video", locale, trans_path);
 }
